Learn R Programming

aniview (version 0.1.0)

use_aniview: Use AniView

Description

Use AniView

Usage

use_aniview(animateThreshold = 0, scrollPollInterval = 20)

Arguments

animateThreshold

integrer. +ve numbers delay the animation sequence until the specified number of pixels have come into view. -ve numbers will trigger the animation sequence prior to the element coming into view.

scrollPollInterval

integrer. frequency at which user scrolling is 'polled' i.e. tested. This is in milliseconds and is an extension to jQuery's in-built 'scroll' event/handler.

Examples

Run this code
# NOT RUN {
library(shiny)

ui <- function(){
fluidPage(
  use_aniview(), # add use_aniview() in the UI
  aniview(h1("Shiny with AniView"), animation = "fadeInUp"),
  aniview(textOutput("text"), animation = "zoomIn")
)
}

server <- function(input, output, session){
 output$text <- renderText({
   print("An animated text.")
 })
}

if(interactive()) shinyApp(ui, server)

# }

Run the code above in your browser using DataLab